@@ -82,8 +82,7 @@
 #'          \item Random-Intercept-Slope-correlation: rho.01
 #'         }
 #'
-#' @seealso \code{\link{re_var}} to print random effect variances and \code{\link{get_re_var}}
-#'            to get the values from a particular variance component.
+#' @seealso \code{\link{re_var}}
 #'
 #' @examples
 #' library(lme4)
@@ -231,25 +230,45 @@ icc.lme4 <- function(fit, obj.name) {
 
 #' @title Random effect variances
 #' @name re_var
-#' @description This function extracts the random effect variances as well as
-#'                the random-intercept-slope-correlation of mixed effects models.
+#' @description These functions extracts random effect variances as well as
+#'                random-intercept-slope-correlation of mixed effects models.
 #'                Currently, only \code{\link[lme4]{merMod}} objects
 #'                are supported.
 #'
 #' @param x Fitted mixed effects model (\code{\link[lme4]{merMod}}-class).
+#'          \code{get_re_var()} also accepts an object of class \code{icc.lme4},
+#'          as returned by the \code{\link{icc}} function.
+#' @param comp Name of the variance component to be returned. See 'Details'.
 #'
-#' @return \code{NULL}, as this is just a convenient \code{print}-wrapper for
-#'           the variance components returned by the \code{\link{icc}} function.
+#' @return \code{get_re_var()} returns the value of the requested variance component,
+#'           \code{re_var()} returns \code{NULL}.
 #'
 #' @references Aguinis H, Gottfredson RK, Culpepper SA. 2013. Best-Practice Recommendations for Estimating Cross-Level Interaction Effects Using Multilevel Modeling. Journal of Management 39(6): 1490–1528 (\doi{10.1177/0149206313478188})
 #'
-#' @seealso \code{\link{icc}} and \code{\link{get_re_var}}
+#' @details The random effect variances indicate the between- and within-group
+#'         variances as well as random-slope variance and random-slope-intercept
+#'         correlation. Use following values for \code{comp} to get the particular
+#'         variance component:
+#'         \describe{
+#'          \item{\code{"sigma_2"}}{Within-group (residual) variance}
+#'          \item{\code{"tau.00"}}{Between-group-variance (variation between individual intercepts and average intercept)}
+#'          \item{\code{"tau.11"}}{Random-slope-variance (variation between individual slopes and average slope)}
+#'          \item{\code{"tau.01"}}{Random-Intercept-Slope-covariance}
+#'          \item{\code{"rho.01"}}{Random-Intercept-Slope-correlation}
+#'         }
+#'
+#' @seealso \code{\link{icc}}
 #'
 #' @examples
 #' library(lme4)
 #' fit1 <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
+#'
+#' # all random effect variance components
 #' re_var(fit1)
 #'
+#' # just the rand. slope-intercept covariance
+#' get_re_var(fit1, "tau.01")
+#'
 #' sleepstudy$mygrp <- sample(1:45, size = 180, replace = TRUE)
 #' fit2 <- lmer(Reaction ~ Days + (1 | mygrp) + (Days | Subject), sleepstudy)
 #' re_var(fit2)
@@ -263,54 +282,11 @@ re_var <- function(x) {
 }
 
 
-#' @title Random effect variances
-#' @name get_re_var
-#' @description This function extracts specific components from the random effect
-#'                variances or the random-intercept-slope-correlation of mixed
-#'                effects models. Currently, only \code{\link[lme4]{merMod}} objects
-#'                are supported.
-#'
-#' @param x An object of class \code{icc.lme4}, as returned by the \code{\link{icc}} function,
-#'          or a fitted mixed effects model (\code{\link[lme4]{merMod}}-class).
-#' @param comp Name of the variance component to be returned. See 'Details'.
-#'
-#' @return The required variance component.
-#'
-#' @seealso \code{\link{icc}} and \code{\link{re_var}}
-#'
-#' @details The random effect variances indicate the between- and within-group
-#'         variances as well as random-slope variance and random-slope-intercept
-#'         correlation. Use following values for \code{comp} to get the particular
-#'         variance component:
-#'         \describe{
-#'          \item{\code{"sigma_2"}}{Within-group (residual) variance}
-#'          \item{\code{"tau.00"}}{Between-group-variance (variation between individual intercepts and average intercept)}
-#'          \item{\code{"tau.11"}}{Random-slope-variance (variation between individual slopes and average slope)}
-#'          \item{\code{"tau.01"}}{Random-Intercept-Slope-covariance}
-#'          \item{\code{"rho.01"}}{Random-Intercept-Slope-correlation}
-#'         }
-#'
-#' @examples
-#' library(lme4)
-#' fit <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
-#'
-#' # icc
-#' icc(fit)
-#'
-#' # all random effect variance components
-#' re_var(fit)
-#'
-#' # just the rand. slope-intercept covariance
-#' get_re_var(fit, "tau.01")
-#'
-#' sleepstudy$mygrp <- sample(1:45, size = 180, replace = TRUE)
-#' fit <- lmer(Reaction ~ Days + (1 | mygrp) + (Days | Subject), sleepstudy)
-#' get_re_var(fit, "rho.01")
-#'
+#' @rdname re_var
 #' @export
 get_re_var <- function(x, comp = c("tau.00", "tau.01", "tau.11", "rho.01", "sigma_2")) {
   # check if we have a valid object
-  if (!any(class(x) == "icc.lme4") && !is_merMod(x)) {
+  if (!inherits(x, "icc.lme4") && !is_merMod(x)) {
     stop("`x` must either be an object returned by the `icc` function, or a merMod-object.", call. = F)
   }
 
