@@ -8,8 +8,9 @@ utils::globalVariables(c("strap", "models"))
 #'                coefficients (ICC).
 #'
 #' @param x (Numeric) vector, a data frame, a \code{merMod}-object
-#'          as returned by the \code{\link[lme4]{lmer}}-method,
-#'          or a list with estimate and p-value. For the latter case, the list
+#'          as returned by the \code{\link[lme4]{lmer}}-method, an ICC object
+#'          (as obtained by the \code{\link{icc}}-function) or a list with
+#'          estimate and p-value. For the latter case, the list
 #'          must contain elements named \code{estimate} and \code{p.value}
 #'          (see 'Examples' and 'Details').
 #' @param nsim Numeric, the number of simulations for calculating the
@@ -26,15 +27,16 @@ utils::globalVariables(c("strap", "models"))
 #' @details Unlike \code{\link[arm]{se.coef}}, which returns the standard error
 #'            for fixed and random effects separately, this function computes
 #'            the standard errors for joint (sums of) random and fixed
-#'            effects coefficients. Hence, \code{se} returns the appropriate
+#'            effects coefficients. Hence, \code{se()} returns the appropriate
 #'            standard errors for \code{\link[lme4]{coef.merMod}}.
 #'            \cr \cr
 #'            The standard error for the \code{\link{icc}} is based on bootstrapping,
 #'            thus, the \code{nsim}-argument is required. See 'Examples'.
 #'            \cr \cr
-#'            \code{se} also returns the standard error of an estimate (regression
+#'            \code{se()} also returns the standard error of an estimate (regression
 #'            coefficient) and p-value, assuming a normal distribution to compute
 #'            the z-score from the p-value (formula in short: \code{b / qnorm(p / 2)}).
+#'            See 'Examples'.
 #'
 #'
 #' @examples
@@ -79,7 +81,7 @@ se <- function(x, nsim = 100) {
   if (is_merMod(x)) {
     # return standard error for mixed models
     return(std_merMod(x))
-  } else if (any(class(x) == "icc.lme4")) {
+  } else if (inherits(x, "icc.lme4")) {
     # we have a ICC object, so do bootstrapping and compute SE for ICC
     return(std_e_icc(x, nsim))
   } else if (is.matrix(x) || is.data.frame(x)) {
@@ -108,32 +110,41 @@ se <- function(x, nsim = 100) {
 
 std_e_helper <- function(x) sqrt(var(x, na.rm = TRUE) / length(stats::na.omit(x)))
 
+
 #' @importFrom stats coef setNames
 #' @importFrom lme4 ranef
 std_merMod <- function(fit) {
   se.merMod <- list()
+
   # get coefficients
   cc <- stats::coef(fit)
+
   # get names of intercepts
   inames <- names(cc)
+
   # variances of fixed effects
   fixed.vars <- diag(as.matrix(lme4::vcov.merMod(fit)))
+
   # extract variances of conditional modes
   r1 <- lme4::ranef(fit, condVar = TRUE)
+
   # we may have multiple random intercepts, iterate all
-  for (i in 1:length(cc)) {
+  for (i in seq_len(length(cc))) {
     cmode.vars <- t(apply(attr(r1[[i]], "postVar"), 3, diag))
     seVals <- sqrt(sweep(cmode.vars, 2, fixed.vars, "+"))
+
     # add results to return list
     se.merMod[[length(se.merMod) + 1]] <- stats::setNames(as.vector(seVals[1, ]),
                                                           c("intercept_se", "slope_se"))
   }
+
   # set names of list
   names(se.merMod) <- inames
   return(se.merMod)
 }
 
 
+
 #' @importFrom dplyr "%>%"
 #' @importFrom stats model.frame
 std_e_icc <- function(x, nsim) {
@@ -153,6 +164,7 @@ std_e_icc <- function(x, nsim) {
 
   # check for all required arguments
   if (missing(nsim) || is.null(nsim)) nsim <- 100
+
   # get ICC, and compute bootstrapped SE, than return both
   bstr <- bootstr_icc_se(stats::model.frame(fitted.model), nsim, model.formula, model.family)
 
@@ -164,6 +176,8 @@ std_e_icc <- function(x, nsim) {
   structure(class = "se.icc.lme4", list(result = res, bootstrap_data = bstr))
 }
 
+
+
 #' @importFrom dplyr mutate
 #' @importFrom lme4 lmer glmer
 #' @importFrom utils txtProgressBar
